@@ -3,7 +3,7 @@
 
 
 from ._base import hash_extract_number, pct_extract_number, \
-    PatternMismatchError, hash_pattern_to_glob, pct_pattern_to_glob, \
+    PatternMismatchError, PatternNotFoundError, hash_pattern_to_glob, pct_pattern_to_glob, \
     hash_pattern_to_regex, NumbersCountError, filename_to_pct_pattern, \
     filename_to_hash_pattern, pct_to_hash_pattern, pct_pattern_to_regex, \
     is_pattern, Format
